@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 from holmes.facters import Facter
+from holmes.utils import _
 
 
 class TitleFacter(Facter):
@@ -10,9 +11,9 @@ class TitleFacter(Facter):
     def get_fact_definitions(cls):
         return {
             'page.title': {
-                'title': 'Page Title',
+                'title': _('Page Title'),
                 'description': lambda value: value,
-                'category': 'SEO',
+                'category': _('SEO'),
             }
         }
 
@@ -22,6 +23,12 @@ class TitleFacter(Facter):
         if not titles:
             return
 
+        if not titles[0].text:
+            return
+
         self.review.data['page.title_count'] = len(titles)
 
-        self.add_fact(key='page.title', value=titles[0].text)
+        title = titles[0].text.strip()
+
+        self.review.data['page.title'] = title
+        self.add_fact(key='page.title', value=title)
