@@ -2,24 +2,21 @@
 # -*- coding: utf-8 -*-
 
 from holmes.validators.base import Validator
+from holmes.utils import _
 
 
 class ImageAltValidator(Validator):
     @classmethod
-    def get_without_alt_message(cls, value):
+    def get_without_alt_parsed_value(cls, value):
         result = []
         for src, name in value:
             data = '<a href="%s" target="_blank">%s</a>' % (src, name)
             result.append(data)
 
-        return (
-            'Images without alt text are not good for '
-            'Search Engines. Images without alt were '
-            'found for: %s.' % (', '.join(result))
-        )
+        return {'images': ', '.join(result)}
 
     @classmethod
-    def get_alt_too_big_message(cls, value):
+    def get_alt_too_big_parsed_value(cls, value):
         result = []
         for src, name, alt in value['images']:
             data = u'<a href="{}" alt="{}" target="_blank">{}</a>'.format(
@@ -27,20 +24,23 @@ class ImageAltValidator(Validator):
             )
             result.append(data)
 
-        return (
-            'Images with alt text bigger than %d chars are not good for '
-            'Search Engines. Images with a too big alt were '
-            'found for: %s.' % (value['max_size'], ', '.join(result))
-        )
+        return {
+            'max_size': value['max_size'],
+            'images': ', '.join(result)
+        }
 
     @classmethod
     def get_violation_definitions(cls):
         return {
             'invalid.images.alt': {
-                'title': 'Image(s) without alt attribute',
-                'description': cls.get_without_alt_message,
-                'category': 'SEO',
-                'generic_description': (
+                'title': _('Image(s) without alt attribute'),
+                'description': _(
+                    'Images without alt text are not good for '
+                    'Search Engines. Images without alt were '
+                    'found for: %(images)s.'),
+                'value_parser': cls.get_without_alt_parsed_value,
+                'category': _('SEO'),
+                'generic_description': _(
                     'Images without alt attribute are not good for '
                     'search engines. They are searchable by the content '
                     'of this attribute, so if it\'s empty, it cause bad '
@@ -48,18 +48,34 @@ class ImageAltValidator(Validator):
                 )
             },
             'invalid.images.alt_too_big': {
-                'title': 'Image(s) with alt attribute too big',
-                'description': cls.get_alt_too_big_message,
-                'category': 'SEO',
-                'generic_description': (
+                'title': _('Image(s) with alt attribute too big'),
+                'description': _(
+                    'Images with alt text bigger than %(max_size)d chars are '
+                    'not good for search engines. Images with a too big alt '
+                    'were found for: %(images)s.'),
+                'value_parser': cls.get_alt_too_big_parsed_value,
+                'category': _('SEO'),
+                'generic_description': _(
                     'Images with alt text too long are not good to SEO. '
                     'This maximum value are configurable '
                     'by Holmes configuration.'
-                )
+                ),
+                'unit': 'number'
+            }
+        }
+
+    @classmethod
+    def get_default_violations_values(cls, config):
+        return {
+            'invalid.images.alt_too_big': {
+                'value': config.MAX_IMAGE_ALT_SIZE,
+                'description': config.get_description('MAX_IMAGE_ALT_SIZE')
             }
         }
 
     def validate(self):
+        max_alt_size = self.get_violation_pref('invalid.images.alt_too_big')
+
         imgs = self.get_imgs()
 
         result_no_alt = []
@@ -76,7 +92,7 @@ class ImageAltValidator(Validator):
                 name = src.rsplit('/', 1)[-1]
                 if not img_alt:
                     result_no_alt.append((src, name))
-                elif len(img_alt) > self.config.MAX_IMAGE_ALT_SIZE:
+                elif len(img_alt) > max_alt_size:
                     result_alt_too_big.append((src, name, img_alt))
 
         if result_no_alt:
@@ -91,7 +107,7 @@ class ImageAltValidator(Validator):
                 key='invalid.images.alt_too_big',
                 value={
                     'images': result_alt_too_big,
-                    'max_size': self.config.MAX_IMAGE_ALT_SIZE
+                    'max_size': max_alt_size
                 },
                 points=20 * len(result_alt_too_big)
             )
